@@ -66,7 +66,7 @@ class SimpleRestSynapse(Synapse):
 
     def __crud(self, operation):
         entity_name = self.request.entity.apiName
-        super().print(self.get.__name__, self.request)
+        super().print(self.get_by_id.__name__, self.request)
         rest_client = self.get_rest_client() 
         eds = []
         for data in self.request.data:
